%% dx5

%% lens setup
sk16 = [1.617271 1.622861 1.627559];
f4 = [1.611644 1.620578 1.628484];
bk7 = [1.514322 1.51680 1.522376];
baf10 = [1.665791 1.670028 1.679987];
sf10 = [1.720848 1.728250 1.746581];
global cv th rn dn;
cv = [ 0 0 0 0 0 0];
th = [ 0 0 0 0 0 0];
rn = [ 1 sk16(2) 1 f4(2) 1 1];
dn = [ 0 sk16(3)-sk16(1) 0 f4(3)-f4(1) 0 0];

%% adjust powers (one step)

v=[1/50 -1/100]';
[A fz] = calculate_derivatives(@achromat1,v);
v = v - A\fz;
f = achromat1(v);
disp('power merit function');
disp(norm(f))

%% do contours

n=128;
u1 = linspace(-8,8,n);
u2 = linspace(-8,8,n);
map = zeros(n,n);
map1 = map;
map2 = map;
for (r=1:n)
    v(2)=u2(r);
    for (c=1:n)
        v(1)=u1(c);
        f = achromat2(v);
        map(r,c)=f'*f;
        map1(r,c)=f(1);
        map2(r,c)=f(2);
    end
end
z = log10(map)+3;

%% show zero contours

pos = get(gcf,'Position');
pos(3)=480;
pos(4)=480;
set(gcf,'Position',pos);
contour(u1,u2,map2,[0 0],'b');
axis square;
hold on;
contour(u1,u2,map1,[0 0],'k');
hold off;
xlabel('shape of first element');
ylabel('shape of second element');

%% show mesh
mesh(u1,u2,z);
hold on
contour(u1,u2,z,12);
hold off

%% contour

contour(u1,u2,z,12,'LineWidth',1.25);
axis square
xlabel('shape of first element');
ylabel('shape of second element');


%% first design

[s damp sigma] = seek([0 5],@achromat2);

%%

show_progress;

%% second design

subplot(1,1,1);
contour(u1,u2,z,12,'LineWidth',1.25);
axis square
xlabel('shape of first element');
ylabel('shape of second element');

[s damp sigma] = seek([5 -3],@achromat2);

%%

show_progress;

%% gradient search

subplot(1,1,1);
contour(u1,u2,z,12,'LineWidth',1.25);
axis square
xlabel('shape of first element');
ylabel('shape of second element');

v = [0 3]';
p(1,:)=v';
fprintf('%2s %10s %8s %8s\n','n','sigma','pmin','%step');
fz = achromat2(v);
fprintf('%2d %10.4g\n',1,norm(fz));
for k=2:10
    [A fz] = calculate_derivatives(@achromat2,v);
    g = -A'*fz/norm(A'*A);
    [pmin fval]=fminbnd(@func,0,2,[],@achromat2,v,g);
    fprintf('%2d %10.4g %8.4f %8.3f\n',k,fval,pmin,100.0*pmin*norm(g)/norm(v));
    v = v + pmin*g;
    p(k,:)=v';
end
hold on;
plot(p(:,1),p(:,2),'ko-','LineWidth',1.5);
hold off;

%% zoom in

axis([-0.784 -0.776 2.01 2.03]);
